#!/bin/sh


# Created by Thomas Vosegaard
# with inspiration from Frank Thommen, EMBL Heidelberg
# Install Simpson version 4.1.1
#


# Default values
#
NOROOT=0                      # run installer w/o root permissions
BINDIR="/usr/local/bin"       # Binary installation dir
LIBDIR="/usr/share/simpson"   # Library installation dir


CMD=""

# Process commandline switches
#
while [ "$#" -gt 0 ]; do
  case $1 in
    -h|--help)
      echo ""
      echo "USAGE: $0 [-h|--help] [--noroot] [-b bindir|--bindir=bindir] [-l libdir|--libdir=libdir]"
      echo ""
      exit 1
    ;;

    --noroot)
      NOROOT=1;
    ;;

	  -b)
		  shift
		  BINDIR=$1
		;;

		--bindir=*)
		  BINDIR=`echo $1| cut -f2 -d=`
		;;

		-l)
			shift
			LIBDIR=$1
		;;

		--libdir=*)
		  LIBDIR=`echo $1| cut -f2 -d=`
		;;

    *)
      echo "Unknown option \"$1\"..."
      echo ""
      echo "USAGE: $0 [-h|--help] [--noroot] [-b bindir|--bindir=bindir] [-l libdir|--libdir=libdir]"
      echo ""
      exit 1
        
  esac
  shift
done

echo "Installation into directories"
echo "Binary:  $BINDIR"
echo "Library: $LIBDIR"
if [ $NOROOT -eq 0 ]; then
	echo "...Installing as root"
else
	echo "...Not installing as root"
fi

if [ $NOROOT -eq 0 ] && [ "$(id -u)" != "0" ]; then
  echo "Error: Please run this script with root access or run with option --noroot"
  exit 1
fi


if [ "$(uname -m)" != "x86_64" ]; then
  PLATFORM=32
	echo "...Installing for 32 bit system"
else
  PLATFORM=64
	echo "...Installing for 64 bit system"
fi

if [ ! -d $BINDIR ]; then
	echo "...Creating directory $BINDIR"
	$CMD mkdir -p $BINDIR
	if [ ! -d $BINDIR ]; then
		echo "Error: Cannot create directory $BINDIR"
		exit 1
	fi
else
	echo "...Directory $BINDIR exists"
fi

if [ ! -d $LIBDIR ]; then
	echo "...Creating directory $LIBDIR"
	$CMD mkdir -p $LIBDIR
	if [ ! -d $LIBDIR ]; then
		echo "Error: Cannot create directory $LIBDIR"
		exit 1
	fi
else
	echo "...Directory $LIBDIR exists"
fi

echo "...Creating executable $BINDIR/simpson"
if [ x$CMD != "x" ]; then
  echo "#!/bin/sh"
	echo "export TCL_LIBRARY=$LIBDIR/tcl8.6"
	echo "export LD_LIBRARY_PATH=$LIBDIR"
	echo "$LIBDIR/simpson4.1.1 \"\$@\""
else
  echo "#!/bin/sh"                         >  $BINDIR/simpson
	echo "export TCL_LIBRARY=$LIBDIR/tcl8.6" >> $BINDIR/simpson
	echo "export LD_LIBRARY_PATH=$LIBDIR"    >> $BINDIR/simpson
	echo "$LIBDIR/simpson4.1.1 \"\$@\""      >> $BINDIR/simpson
fi

echo "...Setting right permissions for $BINDIR/simpson"
if [ $NOROOT -eq 0 ]; then
  $CMD chown root:root $BINDIR/simpson
fi
$CMD chmod ugo+rx $BINDIR/simpson

echo "...Installing binary and libraries in $LIBDIR"

for l in libblas.so.3gf   \
         libfftw3.so.3    \
         libgfortran.so.3 \
         liblapack.so.3gf \
         libtcl8.6.so     \
         simpson4.1.1; do
  echo "...Installing library $l"
  $CMD cp -f $PLATFORM/$l $LIBDIR
  if [ $NOROOT -eq 0 ]; then
    $CMD chown root:root $LIBDIR/$l
  fi
  $CMD chmod ugo+rx $LIBDIR/$l
done

echo "...Installing tcl8.6 in $LIBDIR"
$CMD cp -r $PLATFORM/tcl8.6 $LIBDIR
if [ $NOROOT -eq 0 ]; then
  $CMD chown -R root:root $LIBDIR/tcl8.6
fi
$CMD chmod -R ugo+rX $LIBDIR/tcl8.6

echo Done

